@@ -14,6 +14,8 @@ Usage::
 import sys
 from typing import IO, Any, Dict, List, Union
 
+from botocore.response import StreamingBody
+
 from .literals import DecimalReturnTypeType, TypeHintType
 
 if sys.version_info >= (3, 8):
@@ -123,7 +125,7 @@ FieldTypeDef = TypedDict(
     "FieldTypeDef",
     {
         "arrayValue": "ArrayValueTypeDef",
-        "blobValue": Union[bytes, IO[bytes]],
+        "blobValue": Union[bytes, IO[bytes], StreamingBody],
         "booleanValue": bool,
         "doubleValue": float,
         "isNull": bool,
@@ -197,7 +199,7 @@ SqlStatementResultTypeDef = TypedDict(
 StructValueTypeDef = TypedDict(
     "StructValueTypeDef",
     {
-        "attributes": List["ValueTypeDef"],
+        "attributes": List[Dict[str, Any]],
     },
     total=False,
 )
@@ -216,7 +218,7 @@ ValueTypeDef = TypedDict(
         "arrayValues": List[Dict[str, Any]],
         "bigIntValue": int,
         "bitValue": bool,
-        "blobValue": Union[bytes, IO[bytes]],
+        "blobValue": Union[bytes, IO[bytes], StreamingBody],
         "doubleValue": float,
         "intValue": int,
         "isNull": bool,
